@@ -21,13 +21,11 @@
 	    (name-and-sec (string-split (list-ref str-and-ver 0) #\/)))
       ;; Test if package-string contains a version number, if wanted
       (if (and (eq? with-version 'with-version) (eq? (length str-and-ver) 1))
-	  (errormsg (string-append (_ "Package string malformed: ")
-				   (_ "no version supplied: ")
-				   package-string) 'fatal))
+	  (errormsg (_ "Package string malformed; no version supplied")
+		    package-string 'fatal))
       ;; Test if package string contains section and name
       (if (or (< (length name-and-sec) 2) (> (length name-and-sec) 2))
-	  (errormsg (string-append (_ "Package string malformed: ")
-				   package-string) 'fatal))
+	  (errormsg (_ "Package string malformed") package-string 'fatal))
       #t)))
 
 (define is-installed?
@@ -52,8 +50,8 @@
 					     ".scm")))
       (if (access? package-file-name F_OK)
 	  (load package-file-name)
-	  (errormsg (string-append (_ "Could not load package file: ")
-				   package-file-name) 'fatal)))))
+	  (errormsg (_ "Could not load package file")
+		    package-file-name 'fatal)))))
 
 ;; In package object PACKAGE-OBJ find release RELEASE.
 ;; If RELEASE is not found, return the first available release.
@@ -84,8 +82,7 @@
 				     group-name ".scm")))
       (if (access? group-file F_OK)
 	  (load group-file)
-	  (errormsg (string-append "Could not load group file: "
-				   group-file) 'fatal)))))
+	  (errormsg (_ "Could not load group file") group-file 'fatal)))))
 
 (define install-group
   (lambda (group-list)
