@@ -46,6 +46,15 @@
 	  #t
 	  #f))))
 
+(define (exec-list directory
+		   cmd-list)
+  (do ((k 0 (1+ k)))
+      ((> k (- (length cmd-list) 1)))
+    (exec (string-append "cd "
+			 directory
+			 "; "
+			 (list-ref cmd-list k)))))
+
 (define patch
   (lambda (directory patch)
     (statusmsg (_ "Applying patch") patch)
@@ -88,18 +97,18 @@
 	   (info-dir-stream (if (access? info-dir R_OK)
 				(opendir info-dir)
 				#f)))
-      (unless (exec (string-append "rm " dir-file))
+      (if (not (exec (string-append "rm " dir-file)))
 	      (errormsg (_ "Could not remove the directory file") dir-file))
 
       (do ((k (readdir info-dir-stream) (readdir info-dir-stream)))
 	  ((eof-object? k))
-	(unless (or (string=? k ".") (string=? k ".."))
-		(if (string-suffix? ".info" k)
-		    (let ((info-file (string-append pkg-dest-dir "/" package-prefix
-						   "/share/info/" k)))
-		      (unless (exec (string-append "install-info " info-file
-						   " " package-prefix
-						   "/share/info/dir"))
-			      (errormsg (_ "Could not install info file")
-					info-file)))))))))
-		
+	(if (not (or (string=? k ".")
+                    (string=? k "..")))
+            (if (string-suffix? ".info" k)
+                (let ((info-file (string-append pkg-dest-dir "/" package-prefix
+                                                "/share/info/" k)))
+                  (if (not (exec (string-append "install-info " info-file
+                                               " " package-prefix
+                                               "/share/info/dir")))
+                      (errormsg (_ "Could not install info file")
+                                info-file)))))))))
